api
===

.. currentmodule:: tonyear

Top level API
~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   calculate_tonyears
   get_baseline_curve
   print_benefit_report

GHG Forcing
~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   joos_2013
   joos_2013_monte_carlo

Internal API
~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   core.get_discounted_curve
   core.write_json
